@@ -2,7 +2,6 @@ import kappadata.common.collators
 import kappadata.common.datasets
 import kappadata.common.transforms
 import kappadata.common.wrappers
-
 # collators
 from .collators import MAEFinetuneMixCollator
 # datasets
@@ -10,5 +9,8 @@ from .datasets.kd_image_folder import KDImageFolder
 # transforms
 from .transforms import BYOLTransform0, BYOLTransform1
 from .transforms import MAEFinetuneTransform
+# norm
+from .transforms.norm.kd_cifar10_norm import KDCifar10Norm
+from .transforms.norm.kd_image_net_norm import KDImageNetNorm
 # wrappers
-from .wrappers import BYOLMultiViewWrapper
\ No newline at end of file
+from .wrappers import BYOLMultiViewWrapper
