@@ -14,7 +14,7 @@ class KDRandomGaussianBlurPIL(KDRandomApplyBase):
         self.gaussian_blur.reset_seed()
 
     def _populate_ctx_on_skip(self, ctx):
-        ctx[self.gaussian_blur.ctx_key] = -1
+        ctx[self.gaussian_blur.ctx_key] = -1.
 
     def _scale_strength(self, factor):
         self.gaussian_blur.scale_strength(factor)
