@@ -1,5 +1,5 @@
 from .kd_mix_wrapper import KDMixWrapper
 from .label_smoothing_wrapper import LabelSmoothingWrapper
-from .multi_view_wrapper import MultiViewWrapper
+from .kd_multi_view_wrapper import KDMultiViewWrapper
 from .one_hot_wrapper import OneHotWrapper
 from .x_transform_wrapper import XTransformWrapper
